@@ -1,5 +1,5 @@
-/***************************************************************************
-*   Copyright (C) 2009 by Georg Hennig <georg.hennig@web.de>              *
+/**************************************************************************
+*   Copyright (C) 2009-2014 by Georg Hennig <georg.hennig@web.de>         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -1186,6 +1186,8 @@ void Data_Provider::parseData()
 //		data_update_time = "";
 	}
 
+	saveLocalData();
+
 	emit ( data_fetched() );
 }
 
